chiark / gitweb /
runlisp.c: Remove long-removed `-C' option from usage synopsis.
[runlisp] / runlisp.c
index 87c478f91c408e783f170006b6c55b19d57a51e7..2573b82d37f816b40eea37ac1d56d3be43697ff2 100644 (file)
--- a/runlisp.c
+++ b/runlisp.c
@@ -202,7 +202,7 @@ usage:\n\
        %s [OPTIONS] [-e EXPR] [-d EXPR] [-p EXPR] [-l FILE]\n\
                [--] [ARGUMENTS ...]\n\
 OPTIONS:\n\
        %s [OPTIONS] [-e EXPR] [-d EXPR] [-p EXPR] [-l FILE]\n\
                [--] [ARGUMENTS ...]\n\
 OPTIONS:\n\
-       [-CDEnqv] [+DEn] [-L SYS,SYS,...] [-c CONF] [-o [SECT:]VAR=VAL]\n",
+       [-DEnqv] [+DEn] [-L SYS,SYS,...] [-c CONF] [-o [SECT:]VAR=VAL]\n",
          progname, progname);
 }
 
          progname, progname);
 }
 
@@ -543,8 +543,7 @@ int main(int argc, char *argv[])
   }
   *tail = 0; lisps.tail = tail;
 
   }
   *tail = 0; lisps.tail = tail;
 
-  /* Make sure that the acceptable and preferred Lisps actually exist. */
-  check_lisps("acceptable", &accept, offsetof(struct lispsys, next_accept));
+  /* Make sure that the preferred Lisps actually exist. */
   check_lisps("preferred", &prefer, offsetof(struct lispsys, next_prefer));
 
   /* If there are no acceptable Lisps, then we'll take all of them. */
   check_lisps("preferred", &prefer, offsetof(struct lispsys, next_prefer));
 
   /* If there are no acceptable Lisps, then we'll take all of them. */
@@ -559,13 +558,14 @@ int main(int argc, char *argv[])
 
   /* Build the final list of Lisp systems in the order in which we'll try
    * them: first, preferred Lisps which are acceptable, and then acceptable
 
   /* Build the final list of Lisp systems in the order in which we'll try
    * them: first, preferred Lisps which are acceptable, and then acceptable
* Lisps which aren't preferred.
    */
   tail = &order.head;
   for (lisp = prefer.head; lisp; lisp = lisp->next_prefer)
     if (lisp->f&LF_ACCEPT) { *tail = lisp; tail = &lisp->next_order; }
   for (lisp = accept.head; lisp; lisp = lisp->next_accept)
    */
   tail = &order.head;
   for (lisp = prefer.head; lisp; lisp = lisp->next_prefer)
     if (lisp->f&LF_ACCEPT) { *tail = lisp; tail = &lisp->next_order; }
   for (lisp = accept.head; lisp; lisp = lisp->next_accept)
-    if (!(lisp->f&LF_PREFER)) { *tail = lisp; tail = &lisp->next_order; }
+    if ((lisp->f&LF_KNOWN) && !(lisp->f&LF_PREFER))
+      { *tail = lisp; tail = &lisp->next_order; }
   *tail = 0;
 
   /* Maybe dump out the various lists of Lisp systems we've collected. */
@@ -559,13 +558,14 @@ int main(int argc, char *argv[])
   /* Build the final list of Lisp systems in the order in which we'll try
    * them: first, preferred Lisps which are acceptable, and then acceptable
-   * Lisps which aren't preferred.
+   * Lisps which are known but not preferred.
    */
   tail = &order.head;
   *tail = 0;
 
   /* Maybe dump out the various lists of Lisp systems we've collected. */